#!/usr/bin/env python
# coding: utf-8

# In[ ]:

"""Welcome to gwaihir, there is one submodule used for the gui.

The terminal scripts used for quick analysis are in the terminal_scripts
folder
"""

__all__ = ["gui", "scripts", "support", "plot", "utilities", "version"]
